@@ -893,7 +893,7 @@ class Ec2EnvironmentProps:
             CfnOutput(self, "URL", value=c9env.ide_url)
         '''
         if isinstance(subnet_selection, dict):
-            subnet_selection = SubnetSelection(**subnet_selection)
+            subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
         if __debug__:
             type_hints = typing.get_type_hints(Ec2EnvironmentProps.__init__)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
